@@ -1,10 +1,8 @@
-context("as_matrix.R")
-
 x <- correlate(mtcars, diagonal = 1)
 y <- as_matrix(x)
 
 test_that("Inherits correct classes", {
-  expect_is(y, "matrix")
+  expect_type(y, "double")
 })
 
 test_that("Converts values accurately", {
